#
# spec file for package eiciel
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _libnautilus_extensiondir %(pkg-config --variable extensiondir libnautilus-extension-4)

Name:           eiciel
Version:        0.10.0
Release:        1.1
Summary:        GNOME ACL viewer and editor
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            https://rofi.roger-ferrer.org/eiciel/
Source0:        https://github.com/rofirrim/eiciel/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source99:       %{name}.rpmlintrc

BuildRequires:  gcc-c++
BuildRequires:  itstool
BuildRequires:  libacl-devel
BuildRequires:  meson >= 0.57
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(giomm-2.68) >= 2.68
BuildRequires:  pkgconfig(gtkmm-4.0) >= 4.6
BuildRequires:  pkgconfig(libnautilus-extension-4) >= 43

%description
Eiciel allows you to visually edit file ACL entries. You can add and
remove users and groups who will be granted permissions through the
graphical interface

%package -n nautilus-eiciel
Summary:        Nautilus ACL viewer and editor extension
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
Supplements:    (eiciel and nautilus)

%description -n nautilus-eiciel
A Nautilus extension that allows viewing and editing ACL permissions.

%lang_package

%prep
%autosetup -p1

%build
%meson          \
    -D man=true \
    %{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%files
%license COPYING
%doc AUTHORS README.md
%{_bindir}/eiciel
%{_mandir}/man1/eiciel.1%{?ext_man}
%{_datadir}/applications/org.roger_ferrer.Eiciel.desktop
%{_datadir}/icons/hicolor/*/apps/*eiciel.*
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.roger_ferrer.Eiciel.appdata.xml
# English should be offered to every installation by default.
%{_datadir}/locale/en_GB/
%{_datadir}/locale/en_US/
%{_datadir}/help/C/%{name}

%files -n nautilus-eiciel
%{_libnautilus_extensiondir}/libeiciel-nautilus.so

%files lang -f %{name}.lang
# Those shouldn't be here in the first place.
%exclude %{_datadir}/locale/en_GB/
%exclude %{_datadir}/locale/en_US/

%changelog
* Fri Apr 14 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 0.10.0:
  + Updated translations.
- Drop merged upstream patches:
  0001-Add-man-subdir-to-top-level-meson.build.patch and
  0001-Replace-deprecated-attr-xattr.h-with-sys-xattr.h.patch.
- Move English translations from the lang sub-package to the main
  one. This should offer translations for the main English locales
  without the need to install any additional package by default.
- Add eiciel.rpmlintrc file to filter out the "file-not-in-%%lang"
  RPM Lint warning for the reason above.
* Tue Oct 18 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to 0.10.0.rc2 version:
  + This is a fully updated version to gtk4 and the new plugin
    interface of GNOME Files 43.
  + This version is meant to be used with GNOME Files 43 (and
    later) and it will not work with any earlier version.
  + The plugin support in GNOME Files 43 has been simplified, so
    edition is not possible inside GNOME Files' Properties dialog.
    Visualisation support has been implemented in GNOME Files. To
    edit ACLs or Extended Attributes, use the contextual menu over
    a file or directory in the files view of GNOME Files, this will
    start Eiciel in edit mode for that file directly.
  + Build system has been fully ported to Meson (Autotools has been
    dropped).
  + The id/app-id has been normalised from org.roger-ferrer.Eiciel
    to org.roger_ferrer.Eiciel everywhere given the inconsistent
    handling of the hyphen in the GNOME stack.
- Drop no longer needed update-desktop-files build requirement and
  suse_update_desktop_file macro.
- Drop no longer needed libattr-devel and fdupes build requirements
  and fdupes macro.
- Update pkgconfig module build requirements (align with Meson
  script):
  + "gtkmm-3.0 >= 3.0.0" to "gtkmm-4.0 >= 4.6";
  + "libnautilus-extension >= 3.0.0" to
    "libnautilus-extension-4 >= 43"
- Add Meson build requirement and replace Autotools macros with
  Meson's (configure/make_build/make_install to meson/meson_build/
  meson_install).
- Add new build requirements: "giomm-2.68 >= 2.68" pkgconfig module
  and itstool.
- Update 'packageand(package1:package2)' obsolete Supplements
  syntax to '(package1 and package2)' for supplementation of eiciel
  and nautilus packages.
- Add 0001-Add-man-subdir-to-top-level-meson.build.patch and
  0001-Replace-deprecated-attr-xattr.h-with-sys-xattr.h.patch
  patches to fix installation of manpage and check for sys/xattr.h
  rather than deprecated attr/xattr.h, respectively.
* Tue May 31 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.9.13.1:
  + Solves a missing file in the archive and adds some
    compatibility support to build on old distributions.
- Changes from version 0.9.13:
  + This update includes the long-requested feature of recursive
    changing of permissions and some minor cleanups (mostly
    non-functional changes).
  + Add meson build system.
- Drop
  0001-Remove-deprecated-dynamic-exception-specifications.patch and
  eiciel-sys-xattr.patch: fixed upstream.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Tue Jun  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add GCC 11 compatibility fix:
  * 0001-Remove-deprecated-dynamic-exception-specifications.patch
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Fri Sep 28 2018 bjorn.lie@gmail.com
- Add eiciel-sys-xattr.patch -- <attr/xattr.h> is deprecated, use
  <sys/xattr.h> instead. Also use sed to replace the relevant parts
  of configure.
- Run spec-cleaner, modernize specfile.
- Apply translation-update also for openSUSE, drop conditionals.
* Wed Jan 17 2018 luc14n0@linuxmail.org
- Update to version 0.9.12.1:
  + Fix desktop file.
- Changes from version 0.9.12:
  + Updates for better integration with AppStream.
- Adopt the use of %%make_install rather than raw make command,
  following the best practices.
- Point fdupes to the data directory instead of the build root,
  which is a practice that must be avoided.
- Conditionalize translation-update-upstream BuildRequires use as
  it's a SLE-only requirement.
- Drop intltool BuildRequires: since upstream migrated to Gettext
  it's no longer needed anymore.
* Fri Aug 11 2017 fcrozat@suse.com
- Remove BuildRequires on libgnomeui-devel and conditional build
  against gtk2.
* Thu May 12 2016 dimstar@opensuse.org
- Do not delete the .desktop file. It is needed for AppStream
  processes to have a valid reference.
- Add update-desktop-files BuildRequires.
- Change Categories of eiciel.desktop to System;Filesystem.
* Fri Oct  9 2015 gour@atmarama.net
- Update to version 0.9.11:
  + Updated translations.
- Changes from version 0.9.10:
  + Fixes a problem with GTK+3.14 where checkboxes in the Access
    Control List were not properly rendered.
* Wed Aug 20 2014 dimstar@opensuse.org
- Update to version 0.9.9:
  + A new filter box
  + Several changes in the UI to make it a bit more consistent with
    the GNOME HIG.
  + Help has been ported from DocBook to Mallard.
* Fri Aug  8 2014 dimstar@opensuse.org
- Update to version 0.9.8.3:
  + This version does not include any new feature but better
    integration with PackageKit.
* Tue Nov 26 2013 dimstar@opensuse.org
- Update to version 0.9.8.2:
  + Fix for ineffective permissions not correctly rendered in
    GNOME 3.
- Remove hack to remove executable bit from Authors: fixed
  upstream.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Wed Jun  1 2011 vuntz@opensuse.org
- Do not fail to build if %%gtk2_favor is not defined: just use
  0%%{?gtk2_favor}.
* Sun May 22 2011 dimstar@opensuse.org
- Update to version 0.9.8.1:
  + Allow building against GNOME 3 libraries.
- Pass --disable-static to configure
- Remove --with-nautilus-extensions-dir from configure: it is
  correctly detected based on the libnautilus-extension.pc file.
- Build based on gtk2_favor either for gnome2 or for gnome3
- Add BuildRequires for gnome 3 build:
  + pkgconfig(gtkmm-3.0)
  + pkgconfig(libnautilus-extension) => 3.0.0
- Change BuildRequires for gnome2 build to pkgconfig()-style:
  + Old ones: gtkmm24-devel, libnautilus-devel
  + New ones: gtkmm-2.4, libnautilus.extension
* Mon Feb 14 2011 sbrabec@suse.cz
- Translations migrated to translation-update-upstream.
* Sun Feb 13 2011 vuntz@opensuse.org
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Wed Aug  4 2010 dimstar@opensuse.org
- Update to version 0.9.8:
  + Various bugfixes
  + Translation updates.
- Drop unused patch: eiciel-library-packaging.patch
- Supplement nautilus and eiciel with nautilus-eiciel.
- AUTHORS is non-executable.
* Mon Jun 21 2010 dimstar@opensuse.org
- Update to version 0.9.7:
  + This is a catch-up with all the Debian patches
  + Source code has been translated to english to facilitate the
    start for new contributors
* Mon Mar  9 2009 vuntz@novell.com
- Drop eiciel-gcc4.3-fixes.patch: it's not used, and if it's not
  needed anymore, we can drop it.
- Remove AutoReqProv: it's default now.
- Remove check for old version of openSUSE.
- Remove unneeded BuildRequires: gnome-desktop-devel, gnutls-devel,
  libglade2-devel, libgnomeprintui-devel, libwnck-devel,
  perl-XML-Parser, update-desktop-files.
- Add BuildRequires to fix build: libgnomeui-devel.
* Mon Jan 12 2009 mauro@suse.de 
- Translations update.
* Sat Dec  6 2008 mauro@suse.de
- Updated translations.
* Fri Sep 12 2008 maw@suse.de
- Update to version 0.9.6.1:
  + Minor bugfixes.
* Tue Mar  4 2008 jpr@suse.de
- Update to 0.9.5.1
  * Make help launching more robust
* Wed Nov  7 2007 maw@suse.de
- Add eiciel-gcc4.3-fixes.patch.
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Thu Aug  9 2007 maw@suse.de
- Fix up the -lang subpackage.
* Tue Aug  7 2007 mauro@suse.de
- Split out a -lang subpackage
- Add %%fdupes stuff
* Wed Jan 31 2007 jhargadon@suse.de
- added eiciel to Requires of nautilus-eiciel subpackage (#239732)
- specfile cleanup
* Fri Jan 26 2007 jhargadon@suse.de
- fixed a shared library packaging bug (#238541)
* Thu Jan 25 2007 ro@suse.de
- GNOME moved to /usr
* Wed Dec 13 2006 jpr@suse.de
- Update to 0.9.4, bugfix release to improve compatibility with
  filesystems implemented using FUSE
* Wed Sep 20 2006 jpr@suse.de
- Fix 64 bit builds by ensure that the nautilus extensions are
  searched for in %%{_lib} not lib
* Mon Aug 28 2006 jpr@suse.de
- Eiciel a plugin for nautilus to handle posix ACLs
